@@ -6,3 +6,6 @@ def monkey_patch():
     from psycogreen import gevent
     monkey.patch_all()
     gevent.patch_psycopg()
+
+    import requests_unixsocket
+    requests_unixsocket.monkeypatch()
